Translation Memory — Pootle 2.5.1 documentation

# Translation Memory

Changed in version 2.5.

Pootle provides suggested translations to the current string. Translator can use these suggestions for the translation.

Suggestions are based on previous translations of similar strings. These Translation Memory (TM) matches mean that you can speed up your translation and ensure consistency across your work.

## Using Translation Memory

Translation Memory suggestions are automatically retrieved when you enter a new translation unit. These are displayed below the editing widget. You can insert a TM suggestion by clicking on the suggestion row.

The differences between the current string and the suggested string are highlighted, this allows you to see how the two differ and helps you make changes to the suggestion to make it work as the current translation.

## Configuring Translation Memory

Translation Memory will work out of the box with a default Pootle installation. By default Pootle will query Translate’s Amagama Translation Memory server, which hosts translations of an extensive collection of Opensource software.

If you want to setup and connect to your own TM server then the `AMAGAMA_URL` will allow you to point to a private TM server.